@@ -53,6 +53,11 @@ class EnumFieldMixin(six.with_metaclass(models.SubfieldBase)):
 
         return super(EnumFieldMixin, self).get_default()
 
+    def deconstruct(self):
+        name, path, args, kwargs = super(EnumFieldMixin, self).deconstruct()
+        kwargs['enum'] = self.enum
+        return name, path, args, kwargs
+
 
 class EnumField(EnumFieldMixin, models.CharField):
     def __init__(self, enum, *args, **kwargs):
@@ -65,10 +70,14 @@ class EnumIntegerField(EnumFieldMixin, models.IntegerField):
     def get_prep_value(self, value):
         if value is None:
             return None
-        elif isinstance(value, Enum):
+
+        if isinstance(value, Enum):
             return value.value
-        else:
+
+        try:
             return int(value)
+        except ValueError:
+            return self.to_python(value).value
 
 
 # South compatibility stuff
